# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import pinax.pages.models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='File',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('file', models.FileField(upload_to=pinax.pages.models.generate_filename)),
                ('created', models.DateTimeField(default=django.utils.timezone.now)),
            ],
        ),
        migrations.CreateModel(
            name='Page',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('title', models.CharField(max_length=100)),
                ('path', models.CharField(unique=True, max_length=100)),
                ('body', models.TextField()),
                ('body_html', models.TextField(editable=False, blank=True)),
                ('status', models.IntegerField(default=2, choices=[(1, 'Draft'), (2, 'Public')])),
                ('publish_date', models.DateTimeField(default=django.utils.timezone.now)),
                ('created', models.DateTimeField(default=django.utils.timezone.now, editable=False)),
                ('updated', models.DateTimeField(default=django.utils.timezone.now, editable=False)),
            ],
        ),
    ]



import re

from django.core.exceptions import ValidationError
from django.utils.translation import ugettext_lazy as _


class DefaultHookSet(object):

    def __init__(self):
        from .conf import settings  # if put globally there is a race condition
        self.settings = settings

    def parse_content(self, content):
        return self.settings.PINAX_PAGES_MARKUP_RENDERER(content)

    def validate_path(self, path):
        if not re.match(self.settings.PINAX_PAGES_PAGE_REGEX, path):
            raise ValidationError({
                "path": [
                    _("Path can only contain letters, numbers and hyphens and end with /")
                ]
            })


class HookProxy(object):

    def __getattr__(self, attr):
        from .conf import settings  # if put globally there is a race condition
        return getattr(settings.PINAX_PAGES_HOOKSET, attr)


hookset = HookProxy()



from django.conf.urls import url

from .conf import settings
from .views import file_index, file_create, file_download, file_delete, page_edit, page


urlpatterns = [
    url(r"^files/$", file_index, name="file_index"),
    url(r"^files/create/$", file_create, name="file_create"),
    url(r"^files/(\d+)/([^/]+)$", file_download, name="file_download"),
    url(r"^files/(\d+)/delete/$", file_delete, name="file_delete"),
    url(r"^(?P<path>%s)_edit/$" % settings.PINAX_PAGES_PAGE_REGEX, page_edit, name="pages_page_edit"),
    url(r"^(?P<path>%s)$" % settings.PINAX_PAGES_PAGE_REGEX, page, name="pages_page"),
]



from django.utils import timezone

from django.db import models


class PublishedPageManager(models.Manager):

    def get_queryset(self):
        qs = super(PublishedPageManager, self).get_queryset()
        return qs.filter(publish_date__lte=timezone.now())



from importlib import import_module

from django.core.exceptions import ImproperlyConfigured


def load_path_attr(path):
    i = path.rfind(".")
    module, attr = path[:i], path[i + 1:]
    try:
        mod = import_module(module)
    except ImportError as e:
        raise ImproperlyConfigured("Error importing %s: '%s'" % (module, e))
    try:
        attr = getattr(mod, attr)
    except AttributeError:
        raise ImproperlyConfigured("Module '%s' does not define a '%s'" % (module, attr))
    return attr



from __future__ import unicode_literals

from django.conf import settings  # noqa

from appconf import AppConf

from .utils import load_path_attr


class PinaxPagesAppConf(AppConf):

    HOOKSET = "pinax.pages.hooks.DefaultHookSet"
    PAGE_REGEX = r"(([\w-]{1,})(/[\w-]{1,})*)/"
    MARKUP_RENDERER = "markdown.markdown"

    def configure_markup_renderer(self, value):
        return load_path_attr(value)

    def configure_hookset(self, value):
        return load_path_attr(value)()

    class Meta:
        prefix = "pinax_pages"
